
#ifndef CREDENTIALS_H
#define CREDENTIALS_H
#include "mbed.h"

/// This section helps manage the credentials. I don't like the examples
/// that show clear text credentials, even if they are simply the
/// access point ssid and passphrase. So, I created this to let me
/// edit a simple file on the file system and put them in there.
/// Marginally more secure, but at least not in the source code that
/// I might inadvertently share with others.
///
typedef struct {
    char * ssid;
    char * pass;
} credentials;

#define CREDENTIAL_SIZE 50

/** Read credentials from a file.
*
* This reads a file constructed for hosting the credentials needed
* to sign on to a WiFy access point.
*
* @param filename of interest that hosts the credentials.
* @param cr is the credentials structure that is populated with the credentials.
* @returns true if it successfully read the credentials, false otherwise.
*/
bool ReadCredentials(char * file, credentials * cr);

/** Free the credentials structure to reduce ram usage.
* 
* This will release the resources, but before it does so it will
* wipe the memory, so the credentials are not left in memory.
*
* @param cr is the credentials structure.
*/
void FreeCredentials(credentials * cr);

#endif // CREDENTIALS_H